@@ -505,6 +505,134 @@ static GtkActionEntry status_menu_entries[] =
 	}
 };
 
+static GtkActionEntry log_menu_entries[] =
+{
+	{
+		"GitLogShowDiff",
+		NULL,
+		N_("Show commit diff"),
+		NULL,
+		NULL,
+		G_CALLBACK (on_commit_diff_button_clicked)
+	},
+	{
+		"GitLogCherryPick",
+		NULL,
+		N_("Cherry pick"),
+		NULL,
+		NULL,
+		G_CALLBACK (on_git_log_cherry_pick_activated)
+	},
+	{
+		"GitLogRevert",
+		NULL,
+		N_("Revert"),
+		NULL,
+		NULL,
+		G_CALLBACK (on_git_log_revert_activated)
+	},
+	{
+		"GitLogReset",
+		NULL,
+		N_("Reset..."),
+		NULL,
+		NULL,
+		G_CALLBACK (on_git_log_reset_activated)
+	}
+};
+
+static GtkActionEntry branch_menu_entries[] =
+{
+	{
+		"GitBranchSwitch",
+		NULL,
+		N_("Switch"),
+		NULL,
+		NULL,
+		G_CALLBACK (on_switch_branch_button_clicked)
+	},
+	{
+		"GitBranchDelete",
+		NULL,
+		N_("Delete..."),
+		NULL,
+		NULL,
+		G_CALLBACK (on_git_branch_delete_activated)
+	},
+	{
+		"GitBranchMerge",
+		NULL,
+		N_("Merge..."),
+		NULL,
+		NULL,
+		G_CALLBACK (on_git_branch_merge_activated)
+	}
+};
+
+static GtkActionEntry remote_menu_entries[] =
+{
+	{
+		"GitRemotePush",
+		NULL,
+		N_("Push..."),
+		NULL,
+		NULL,
+		G_CALLBACK (on_push_button_clicked)
+	},
+	{
+		"GitRemotePull",
+		NULL,
+		N_("Pull..."),
+		NULL,
+		NULL,
+		G_CALLBACK (on_pull_button_clicked)
+	},
+	{
+		"GitRemoteFetch",
+		NULL,
+		N_("Fetch"),
+		NULL,
+		NULL,
+		G_CALLBACK (on_fetch_button_clicked)
+	}
+};
+
+static GtkActionEntry stash_menu_entries[] =
+{
+	{
+		"GitStashApply",
+		NULL,
+		N_("Apply"),
+		NULL,
+		NULL,
+		G_CALLBACK (on_apply_stash_button_clicked)
+	},
+	{
+		"GitStashApplyIndex",
+		NULL,
+		N_("Apply and restore index"),
+		NULL,
+		NULL,
+		G_CALLBACK (on_apply_stash_index_button_clicked)
+	},
+	{
+		"GitStashDiff",
+		NULL,
+		N_("Diff"),
+		NULL,
+		NULL,
+		G_CALLBACK (on_diff_stash_button_clicked)
+	},
+	{
+		"GitStashDrop",
+		NULL,
+		N_("Drop"),
+		NULL,
+		NULL,
+		G_CALLBACK (on_drop_stash_button_clicked)
+	}
+};
+
 static gpointer parent_class;
 
 static void
@@ -750,6 +878,29 @@ git_activate_plugin (AnjutaPlugin *plugin)
 	                                                                    status_menu_entries, 
 	                                                                    G_N_ELEMENTS (status_menu_entries), 
 	                                                                    GETTEXT_PACKAGE, FALSE, plugin);
+	git_plugin->log_menu_group = anjuta_ui_add_action_group_entries (ui, "GitLogPopup",
+	                                                                 _("Log popup menu"),
+	                                                                 log_menu_entries,
+	                                                                 G_N_ELEMENTS (log_menu_entries),
+	                                                                 GETTEXT_PACKAGE,
+	                                                                 FALSE, plugin);
+	git_plugin->branch_menu_group = anjuta_ui_add_action_group_entries (ui, "GitBrancPopup",
+	                                                                    _("Branch popup menu"),
+	                                                                    branch_menu_entries,
+	                                                                    G_N_ELEMENTS (branch_menu_entries),
+	                                                                    GETTEXT_PACKAGE,
+	                                                                    FALSE, plugin);
+	git_plugin->remote_menu_group = anjuta_ui_add_action_group_entries (ui, "GitRemotePopup",
+	                                                                    _("Remote popup menu"),
+	                                                                    remote_menu_entries,
+	                                                                    G_N_ELEMENTS (remote_menu_entries),
+	                                                                    GETTEXT_PACKAGE, FALSE, plugin);
+	git_plugin->stash_menu_group = anjuta_ui_add_action_group_entries (ui, "GitStashPopup",
+	                                                                   _("Popup menu entries"),
+	                                                                   stash_menu_entries,
+	                                                                   G_N_ELEMENTS (stash_menu_entries),
+	                                                                   GETTEXT_PACKAGE,
+	                                                                   FALSE, plugin);
 
 	
 	/* Create the branch list commands. There are two commands because some 
@@ -889,6 +1040,10 @@ git_deactivate_plugin (AnjutaPlugin *plugin)
 
 	ui = anjuta_shell_get_ui (plugin->shell, NULL);
 	anjuta_ui_remove_action_group (ui, git_plugin->status_menu_group);
+	anjuta_ui_remove_action_group (ui, git_plugin->log_menu_group);
+	anjuta_ui_remove_action_group (ui, git_plugin->branch_menu_group);
+	anjuta_ui_remove_action_group (ui, git_plugin->remote_menu_group);
+	anjuta_ui_remove_action_group (ui, git_plugin->stash_menu_group);
 	anjuta_ui_unmerge (ui, git_plugin->uiid);
 
 	g_object_unref (git_plugin->local_branch_list_command);
